@@ -1,7 +1,7 @@
 import requests
 import socket
 
-from AuthGG.errors import error_handler
+from AuthGG import error_handler
 
 class Logging:
     def __init__(self, aid: str, apikey: str, secret: str):
